pub fn is_valid_zv(inv_list_zv: &ZeroVec<'_, PotentialCodePoint>) -> boolExpand description
Returns whether the vector is sorted ascending non inclusive, of even length,
and within the bounds of 0x0 -> 0x10FFFF + 1 inclusive.
pub fn is_valid_zv(inv_list_zv: &ZeroVec<'_, PotentialCodePoint>) -> boolReturns whether the vector is sorted ascending non inclusive, of even length,
and within the bounds of 0x0 -> 0x10FFFF + 1 inclusive.